@@ -1,5 +1,5 @@
 package Pod::Autopod; ## Generates pod documentation by analysing perl modules.
-$Pod::Autopod::VERSION = '1.212';
+$Pod::Autopod::VERSION = '1.213';
 use 5.006; #Pod::Abstract uses features of 5.6
 use FileHandle;
 use strict;
@@ -679,7 +679,9 @@ my $file=shift;
 		}
 
 
-		if ($self->{'STATE'} eq 'head'){
+
+		## list items
+		if ( ($self->{'STATE'} eq 'head') || ($self->{'STATE'} eq 'free') ){
 
 			if ($line=~ m/^\s*#\s*-\s+(.*)/){ # minus
 				my $text = $1;
